@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,14 +36,21 @@
  * եɤ߹९饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
 {
+    /**
+     * ٥̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $event = 'executeStream';
     /**
      * ƥʥ̾
      * 
@@ -108,15 +115,12 @@ class SyL_ConfigActions extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName();
-            $cache =& SyL_Cache::getObject($key, 'fileupdate');
-            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/actions');
-            $this->config = $cache->read($this->file_names);
-            if (!$this->config) {
+            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'actions', $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName());
+            if ($cache) {
                 parent::parseXml();
                 // åѥ᡼¸
                 $this->config[$this->action_cache_key] = $this->action_cache_value;
-                $cache->write($this->config);
+                $cache->write($this->getCache());
             } else {
                 // åѥ᡼
                 $this->action_cache_value = $this->config[$this->action_cache_key];
@@ -191,6 +195,8 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$name]['priority'] = $this->default_priority;
                 // 󥹥ȥ饯󥸥ե饰
                 $this->config[$name]['constructor'] = false;
+                // ե뤬¸ߤʤȥ顼Υե饰
+                $this->config[$name]['force'] = (SYL_ENV_TYPE == 'cmd'); // ޥɥ饤Τߥե¸ߥå
                 // ٥ȥʥ֥Ⱥ
                 $this->config[$name]['event'][$this->event][] = $name;
                 // 
@@ -259,6 +265,8 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$component_name]['priority'] = $component_priority;
                 // 󥹥ȥ饯󥸥ե饰
                 $this->config[$component_name]['constructor'] = false;
+                // ե뤬¸ߤʤȥ顼Υե饰
+                $this->config[$component_name]['force'] = false;
                 // ٥ȥ
                 $this->config[$component_name]['event'][$this->event][] = $component_name;
                 // 
