@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,14 +36,21 @@
  * ݡͥեɤ߹९饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
 {
+    /**
+     * ٥̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $event = 'initStream';
     /**
      * ǥեȼ¹Խ
      * 
@@ -61,13 +68,10 @@ class SyL_ConfigComponents extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = implode('', $this->file_names);
-            $cache =& SyL_Cache::getObject($key, 'fileupdate');
-            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/components');
-            $this->config = $cache->read($this->file_names);
-            if (!$this->config) {
+            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'components');
+            if ($cache) {
                 parent::parseXml();
-                $cache->write($this->config);
+                $cache->write($this->getCache());
             }
         } else {
             // åѤʤ
@@ -108,6 +112,8 @@ class SyL_ConfigComponents extends SyL_Config
             $this->config[$name]['priority'] = isset($attribute['priority']) ? (int)$attribute['priority'] : $this->default_priority;
             // 󥹥ȥ饯󥸥ե饰
             $this->config[$name]['constructor'] = false;
+            // ե뤬¸ߤʤȥ顼Υե饰
+            $this->config[$name]['force'] = false;
             // ٥ȥ
             $event = isset($attribute['event']) ? $attribute['event'] : $this->event;
             $this->config[$name]['event'][$event][] = $name;
