@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.13 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,14 +36,22 @@
  * եɤ߹ߡ륯饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.13 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
 {
+    /**
+     * å
+     * 
+     * @access private
+     * @var string
+     */
+    var $cache = '';
+
     /**
      * XMLեβϽ
      *
@@ -53,13 +61,10 @@ class SyL_ConfigDefines extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = implode('', $this->file_names);
-            $cache =& SyL_Cache::getObject($key, 'fileupdate');
-            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/defines');
-            $this->config = $cache->read($this->file_names);
-            if (!$this->config) {
+            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'defines');
+            if ($cache) {
                 parent::parseXml();
-                $cache->write($this->config);
+                $cache->write($this->getCache());
             }
         } else {
             // åѤʤ
@@ -69,7 +74,6 @@ class SyL_ConfigDefines extends SyL_Config
 
     /**
      * XMLǡƼϥɥ᥽å
-     * С饤
      *
      * @access public
      * @param string XMLΥѥ
@@ -79,10 +83,55 @@ class SyL_ConfigDefines extends SyL_Config
     function getElement($current_path, $attribute, $text)
     {
         if ($current_path == '/syl-defines/define') {
-            $this->config[$attribute['name']] = $text;
+            if (defined($attribute['name'])) {
+                // Ѥߤϥå
+                return;
+            }
+            $value = $this->readDefine($attribute['name'], $text);
+            $def   = "define('{$attribute['name']}', \"{$value}\");";
+            $this->cache .= $def . "\n";
+            eval($def);
         }
     }
 
+    /**
+     * ɤ߹
+     *
+     * @access public
+     * @param string ե̾
+     * @param object ȥ饪֥
+     */
+    function readDefine($name, $value)
+    {
+        $value = " {$value} ";
+        $value = preg_replace_callback('/(.+)\{([^\}]+)\}(.+)/', array(&$this, 'replaceConstant'), $value, 1);
+        $value = substr($value, 1, -1);
+        return $value;
+    }
+
+    /**
+     * ֤Хå᥽å
+     *
+     * @access public
+     * @param array ޥå
+     @ return mixed ޥå
+     */
+    function replaceConstant($matches)
+    {
+        $matches = str_replace('"', '\\"', $matches);
+        return $matches[1] . '".' . $matches[2] . '."' . $matches[3];
+    }
+
+    /**
+     * ꥭå
+     * 
+     * @access public
+     * @return string ꥭå
+     */
+    function getCache()
+    {
+        return $this->cache;
+    }
 }
 
 ?>
