@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,14 +36,21 @@
  * ե륿եɤ߹९饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.13 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.15 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
 {
+    /**
+     * ٥̾
+     * 
+     * @access private
+     * @var string
+     */
+    var $event = 'loadStream';
     /**
      * ե륿٥ȡʥ
      * 
@@ -108,13 +115,10 @@ class SyL_ConfigFilters extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = implode('', $this->file_names) . $this->action_file;
-            $cache =& SyL_Cache::getObject($key, 'fileupdate');
-            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/filters');
-            $this->config = $cache->read($this->file_names);
-            if (!$this->config) {
+            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'filters', $this->action_file);
+            if ($cache) {
                 parent::parseXml();
-                $cache->write($this->config);
+                $cache->write($this->getCache());
             }
         } else {
             // åѤʤ
@@ -158,6 +162,8 @@ class SyL_ConfigFilters extends SyL_Config
                 $this->config[$name]['priority'] = $this->default_priority;
                 // 󥹥ȥ饯󥸥ե饰
                 $this->config[$name]['constructor'] = false;
+                // ե뤬¸ߤʤȥ顼Υե饰
+                $this->config[$name]['force'] = false;
                 // ٥ȥʥ֥Ⱥ
                 $this->config[$name]['event'][$this->event][] = $name;
                 // 
