@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.6 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,10 @@
  * 쥤եɤ߹९饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.5 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.6 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
@@ -74,13 +74,10 @@ class SyL_ConfigLayouts extends SyL_Config
     {
         if (SYL_WEBAPP_CACHE_DIR) {
             // åѤ
-            $key = implode('', $this->file_names) . $this->action_file;
-            $cache =& SyL_Cache::getObject($key, 'fileupdate');
-            $cache->setCacheDir(SYL_WEBAPP_CACHE_DIR . '/layouts');
-            $this->config = $cache->read($this->file_names);
-            if (!$this->config) {
+            $cache =& $this->getCacheObject(SYL_WEBAPP_CACHE_DIR . 'layouts', $this->action_file);
+            if ($cache) {
                 parent::parseXml();
-                $cache->write($this->config);
+                $cache->write($this->getCache());
             }
         } else {
             // åѤʤ
