@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,10 +43,10 @@
  *   5. finalStream      - shutdown
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.7 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
@@ -58,9 +58,9 @@ class SyL_ControllerCmd extends SyL_Controller
      */
     function initStream()
     {
-        // Х륳ݡͥե
         $config_file = array();
-        $config_file['components'] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
+        // Х륳ݡͥե
+        $config_file['components'][] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
         // ٥ȼ¹
         $this->raiseEvent('initStream', $config_file);
     }
@@ -72,9 +72,9 @@ class SyL_ControllerCmd extends SyL_Controller
      */
     function executeStream()
     {
-        // ե
         $config_file = array();
-        $config_file['actions'] = SYL_APP_DIR . "/{$this->action_file_name}";
+        // ե
+        $config_file['actions'][] = SYL_APP_DIR . "/{$this->action_file_name}";
 
         // ٥ȼ¹
         $this->raiseEvent('executeStream', $config_file);
