@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.10 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,6 @@
  */
 require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
 
-// åץɤ줿եΥѡߥå
-define('SYL_UPLOAD_FILE_MODE', 0666);
-
 /**
  * åץɥեݻ饹
  *
@@ -47,14 +44,21 @@ define('SYL_UPLOAD_FILE_MODE', 0666);
  *   󥯥Ȥ롣
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.8 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.10 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestFile extends SyL_UtilProperty
 {
+    /**
+     * åץɤ줿եΥѡߥå
+     * 
+     * @access private
+     * @var int
+     */
+    var $mode = 0666;
     /**
      * åץɥ顼
      * 
@@ -68,7 +72,7 @@ class SyL_RequestFile extends SyL_UtilProperty
      * @access private
      * @var string
      */
-    var $upload_dir = SYL_UPLOAD_DEFAULT_DIR;
+    var $upload_dir = SYL_UPLOAD_DIR;
 
     /**
      * 󥹥ȥ饯
@@ -77,8 +81,6 @@ class SyL_RequestFile extends SyL_UtilProperty
      */
     function SyL_RequestFile()
     {
-        $parameters = array();
-
         if (isset($_FILES)) {
             // ե륭å奯ꥢ
             clearstatcache();
@@ -90,26 +92,25 @@ class SyL_RequestFile extends SyL_UtilProperty
                         if ($value['error'][$i] > 0) {
                             $this->errors[$key][$i] = $this->getErrorMessagePHP($value['error'][$i], $i);
                         } else if ($value['size'][$i] == 0) {
-                            $this->errors[$key][$i] = '[SyL error] upload file is size of 0 (' . ($i+1) . ')';
+                            $this->errors[$key][$i] = "[SyL error] Upload file is size of 0 (" . ($i+1) . ")";
                         } else if (!is_uploaded_file($value['tmp_name'][$i])) {
-                            $this->errors[$key][$i] = "[SyL error] 'is_uploaded_file' function error (" . ($i+1) . ')';
+                            $this->errors[$key][$i] = "[SyL error] 'is_uploaded_file' function error (" . ($i+1) . ")";
                         }
                     }
                 } else {
                     if ($value['error'] > 0) {
                         $this->errors[$key]['0'] = $this->getErrorMessagePHP($value['error']);
                     } else if ($value['size'] == 0) {
-                        $this->errors[$key]['0'] = '[SyL error] upload file is size of 0';
+                        $this->errors[$key]['0'] = "[SyL error] Upload file is size of 0";
                     } else if (!is_uploaded_file($value['tmp_name'])) {
-                        $this->errors[$key]['0'] = "[SyL error] 'is_uploaded_file' function error ";
+                        $this->errors[$key]['0'] = "[SyL error] Upload file 'is_uploaded_file' function error ";
                     }
                 }
             }
 
             // ѥ᡼
-            $parameters =& $_FILES;
+            $this->parameters =& $_FILES;
         }
-        $this->parameters =& $parameters;
     }
 
     /**
@@ -126,12 +127,12 @@ class SyL_RequestFile extends SyL_UtilProperty
             $i = '(' . ($i+1) . ')';
         }
         switch ($errorno) {
-        case UPLOAD_ERR_INI_SIZE:   return '[SyL error] upload size is more than php.ini file ' . $i; break;
-        case UPLOAD_ERR_FORM_SIZE:  return '[SyL error] upload size is more than html form init size ' . $i; break;
-        case UPLOAD_ERR_PARTIAL:    return '[SyL error] upload file can not upload a part of upload file ' . $i; break;
-        case UPLOAD_ERR_NO_FILE:    return '[SyL error] upload file is not exist ' . $i; break;
-        case UPLOAD_ERR_NO_TMP_DIR: return '[SyL error] TMP_DIR undefined ' . $i; break;
-        default:                    return '[SyL error] undefined upload error ' . $i; break;
+        case UPLOAD_ERR_INI_SIZE:   return "[SyL error] Upload size is more than php.ini file {$i}"; break;
+        case UPLOAD_ERR_FORM_SIZE:  return "[SyL error] Upload size is more than html form init size {$i}"; break;
+        case UPLOAD_ERR_PARTIAL:    return "[SyL error] Upload file can not upload a part of upload file {$i}"; break;
+        case UPLOAD_ERR_NO_FILE:    return "[SyL error] Upload file is not exist {$i}"; break;
+        case UPLOAD_ERR_NO_TMP_DIR: return "[SyL error] TMP_DIR undefined {$i}"; break;
+        default:                    return "[SyL error] Undefined upload error (no {$errorno}) {$i}"; break;
         }
     }
 
@@ -151,11 +152,11 @@ class SyL_RequestFile extends SyL_UtilProperty
      * 
      * @access public
      * @param string ե̾
-     * @return string 顼å
+     * @return array 顼å
      */
     function getErrorMessage($name)
     {
-        return (isset($this->errors[$name]) ? $this->errors[$name] : '');
+        return (isset($this->errors[$name]) ? $this->errors[$name] : array());
     }
 
     /**
@@ -164,12 +165,27 @@ class SyL_RequestFile extends SyL_UtilProperty
      * @access public
      * @param string åץɥǥ쥯ȥ
      */
-    function setUploadDir($upload_dir)
+    function setUploadDir($upload_dir, $absolute=false)
     {
-        // åץɥǥ쥯ȥ
-        if ($upload_dir != '') {
-            // ǸΡ/䴰
-            $this->upload_dir = preg_match( '/.*\/$/', $upload_dir) ? $upload_dir : $upload_dir . '/';
+        $upload_dir = str_replace('..', '.', $upload_dir);
+        if (!preg_match('/^(.*)(\/|\\)$/', $upload_dir)) {
+            $upload_dir .= '/';
+        }
+
+        if ($absolute) {
+            $this->upload_dir = $upload_dir;
+        } else {
+            $this->upload_dir = SYL_UPLOAD_DIR . $upload_dir;
+        }
+
+        if (is_dir($this->upload_dir)) {
+            if (!is_writable($this->upload_dir)) {
+                trigger_error("[SyL error] Upload Directory permission denied ({$this->upload_dir})", E_USER_ERROR);
+            }
+        } else {
+            if (!@mkdir($this->upload_dir, $this->mode)) {
+                trigger_error("[SyL error] Upload Directory not found and unable to create directory ({$this->upload_dir})", E_USER_ERROR);
+            }
         }
     }
 
@@ -178,34 +194,28 @@ class SyL_RequestFile extends SyL_UtilProperty
      * 
      * @access public
      * @param string ե̾
-     * @param string åץɥǥ쥯ȥ
      * @return boolean true: åץ, false: åץɥ顼
      */
-    function upload($name, $upload_dir='')
+    function upload($name='')
     {
-        if ($upload_dir != '') {
-            $upload_dir = preg_match( '/.*\/$/', $upload_dir) ? $upload_dir : $upload_dir . '/';
-        } else {
-            $upload_dir = $this->upload_dir;
-        }
+        $files = ($name) ? array($name) : array_keys($this->parameters);
 
         $upload_flag = true;
-
-        $file = $this->get($name);
-        if (is_array($file['tmp_name'])) {
-            for ($i=0; $i<count($file['tmp_name']); $i++) {
-                if ($file['error'][$i] == 0) {
-                    $upload_file = $upload_dir . $file['name'][$i];
-                    if (!$this->_upload($name, $file['tmp_name'][$i], $upload_dir, $upload_file, $i)) {
-                        $upload_flag = false;
+        foreach ($files as $name) {
+            $file = $this->get($name);
+            if (is_array($file['tmp_name'])) {
+                for ($i=0; $i<count($file['tmp_name']); $i++) {
+                    if ($file['error'][$i] == 0) {
+                        if (!$this->_upload($name, $file['tmp_name'][$i], $file['name'][$i], $i)) {
+                            $upload_flag = false;
+                        }
                     }
                 }
-            }
-        } else {
-            if ($file['error'] == 0) {
-                $upload_file = $upload_dir . $file['name'];
-                if (!$this->_upload($name, $file['tmp_name'], $upload_dir, $upload_file)) {
-                    $upload_flag = false;
+            } else {
+                if ($file['error'] == 0) {
+                    if (!$this->_upload($name, $file['tmp_name'], $file['name'])) {
+                        $upload_flag = false;
+                    }
                 }
             }
         }
@@ -217,11 +227,10 @@ class SyL_RequestFile extends SyL_UtilProperty
      * 
      * @access public
      * @param string ե̾
-     * @param string åץɥǥ쥯ȥ
      * @param string åץɥե
      * @return boolean true: åץ, false: åץɥ顼
      */
-    function _upload($name, $tmp_name, $upload_dir, $upload_file, $i='')
+    function _upload($name, $tmp_name, $upload_file, $i='')
     {
         if (is_numeric($i)) {
             $num = '(' . ($i+1) . ')';
@@ -229,38 +238,20 @@ class SyL_RequestFile extends SyL_UtilProperty
             $num = '';
             $i   = '0';
         }
-        if (!is_writable($upload_dir)) {
-            $this->errors[$name][$i] = '[SyL error] permission denied ' . $num . ' (' . $upload_file . ')';
+        if (!is_writable($this->upload_dir)) {
+            $this->errors[$name][$i] = "[SyL error] Upload Directory permission denied {$num} ({$this->upload_dir}{$upload_file})";
             return false;
-        } else if (!@move_uploaded_file($tmp_name, $upload_file)) {
-            $this->errors[$name][$i] = '[SyL error] upload error ' . $num . ' (' . $upload_file . ')';
+        } else if (!@move_uploaded_file($tmp_name, $this->upload_dir . $upload_file)) {
+            $this->errors[$name][$i] = "[SyL error] Upload file 'move_uploaded_file' function error {$num} ({$this->upload_dir}{$upload_file})";
             return false;
         } else {
-            if (SYL_UPLOAD_FILE_MODE != '') {
-                @chmod($upload_file, SYL_UPLOAD_FILE_MODE);
+            if ($this->mode) {
+                @chmod($this->upload_dir . $upload_file, $this->mode);
             }
             return true;
         }
     }
 
-    /**
-     * ե륢åץɼ¹
-     * 
-     * @access public
-     * @param string åץɥǥ쥯ȥ
-     * @return boolean true: åץ, false: åץɥ顼
-     */
-    function uploadAll($upload_dir='')
-    {
-        $upload_flag = true;
-        foreach ($this->parameters as $name => $value) {
-            if (!$this->upload($name, $upload_dir)) {
-                $upload_flag = false;
-            }
-        }
-
-        return $upload_flag;
-    }
 }
 
 ?>
