@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.4 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,10 @@
  * XML᥽åɤե졼ͤ륯饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.2 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.4 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterXmlrpc extends SyL_Router
@@ -58,10 +58,10 @@ class SyL_RouterXmlrpc extends SyL_Router
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$data)
+    function createActionInfo(&$data)
     {
-         // syl_xmlrpc_method => SyL_DataXmlrpc饹ǥåȤ
-        $pathinfo = explode($this->action_delimiter, $data->get('syl_xmlrpc_method'));
+         // SyL_DataXmlrpc饹ǥåȤ
+        $pathinfo = explode($this->action_delimiter, $data->get(0));
 
         switch (count($pathinfo)) {
         case 0:
@@ -79,17 +79,12 @@ class SyL_RouterXmlrpc extends SyL_Router
             break;
         }
 
-        // PATH_INFO
-        $this->pathinfo = $pathinfo;
-
         // 饹ե
-        if ($this->action_file != '') {
-            $classname = implode('_', array_map('ucfirst', $this->pathinfo));
-            if ($classname != '') {
-                $this->class_name = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
-            } else {
-                $this->class_name = ucfirst(basename($this->action_file,$this->exe_ext));
-            }
+        $classname = implode('_', array_map('ucfirst', $pathinfo));
+        if ($classname != '') {
+            $this->action_class = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
+        } else {
+            $this->action_class = ucfirst(basename($this->action_file,$this->exe_ext));
         }
     }
 
