@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.15 2007/04/30 13:15:57 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -45,21 +45,14 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * եɤ߹९饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.14 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.15 2007/04/30 13:15:57 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
 {
-    /**
-     * ٥̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $event = '';
     /**
      * XMLե̾
      * 
@@ -85,11 +78,11 @@ class SyL_Config extends SyL_XmlReader
      * 󥹥ȥ饯
      *
      * @access public
-     * @param string XMLե̾
+     * @param mixed XMLե̾
      */
-    function SyL_Config($file_name)
+    function SyL_Config($file_names)
     {
-        $this->file_names = explode(PATH_SEPARATOR, $file_name);
+        $this->file_names = $file_names;
     }
 
     /**
@@ -97,19 +90,18 @@ class SyL_Config extends SyL_XmlReader
      *
      * @static
      * @access public
-     * @param string ٥̾
      * @param string ե륪֥̾
-     * @param string ե̾
+     * @param array ե̾
      * @param object ȥ饪֥
-     * @return object SyL_Container֥
+     * @param string ٥̾
+     * @return object ե륪֥
      */
-    function &getObject($config_name, $file_name, &$controller, $event='')
+    function &getObject($config_name, $file_names, &$controller)
     {
         $class_name = 'SyL_Config' . ucfirst($config_name);
         include_once SYL_INCLUDE_DIR . "/framework/Config/{$class_name}.php";
-        $obj =& new $class_name($file_name);
+        $obj =& new $class_name($file_names);
         $obj->setController($controller);
-        $obj->setEvent($event);
         return $obj;
     }
 
@@ -124,14 +116,34 @@ class SyL_Config extends SyL_XmlReader
     }
 
     /**
-     * ٥̾򥻥å
+     * å奪֥Ȥ
      *
      * @access public
-     * @param string ٥̾
+     * @param string åǥ쥯ȥ
+     * @param string ɲåʸ
+     * @return object å奪֥
      */
-    function setEvent($event)
+    function &getCacheObject($cache_dir, $ext_key='')
     {
-        $this->event = $event;
+        // åѤ
+        $mtime = 0;
+        foreach ($this->file_names as $file_name) {
+            $mtime_tmp = filemtime($file_name);
+            if ($mtime < $mtime_tmp) {
+                $mtime = $mtime_tmp;
+            }
+        }
+
+        $cache =& SyL_Cache::getObject('fileinclude');
+        $cache->setKey(implode('', $this->file_names) . $ext_key);
+        $cache->setCacheDir($cache_dir);
+        $this->config = $cache->read(false, $mtime);
+        if (!$this->config) {
+            return $cache;
+        } else {
+            $cache = null;
+            return $cache;
+        }
     }
 
     /**
@@ -156,7 +168,6 @@ class SyL_Config extends SyL_XmlReader
 
     /**
      * XMLǡƼϥɥ᥽å
-     * С饤
      *
      * @access protected
      * @param string XMLΥѥ
@@ -170,12 +181,24 @@ class SyL_Config extends SyL_XmlReader
     /**
      * XMLͤ
      * 
+     * @access public
      * @return array 
      */
     function getConfig()
     {
         return $this->config;
     }
+
+    /**
+     * ꥭå
+     * 
+     * @access public
+     * @return string ꥭå
+     */
+    function getCache()
+    {
+        return 'return ' . var_export($this->config, true) . ';';
+    }
 }
 
 ?>
