@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,10 +41,10 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * ƥʥ饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.17 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.19 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -116,32 +116,16 @@ class SyL_Container
     function raiseEvent($event, $config_type=array(), $component_name='')
     {
         // ٥ȳϥ
-        $this->log('debug', "$event event start");
-        // ݻ
-        $tmp_config = array();
+        $this->log('debug', "{$event} event start");
 
         // եɤ߹
-        if ($event == 'appStream') {
-            if ($component_name == '') {
-                // ݡͥȤꤵƤʤȵưʤ
-                return;
-            }
-            if (count($config_type) > 0) {
-                $this->app_config += $this->readConfig($event, $config_type);
-            }
-            if (!isset($this->app_config[$component_name])) {
-                trigger_error("[SyL error] Application Component not exists ({$component_name})", E_USER_ERROR);
-            }
-            $tmp_config[$component_name] =& $this->app_config[$component_name];
-
-        } else {
-            if (count($config_type) > 0) {
-                $this->config += $this->readConfig($event, $config_type);
-                // ̥ͥȽ
-                uasort($this->config, array(&$this, 'sortConfig'));
-            }
-            $tmp_config =& $this->config;
+        if (count($config_type) > 0) {
+            $this->config += $this->readConfig($config_type);
+            // ̥ͥȽ
+            uasort($this->config, array(&$this, 'sortConfig'));
         }
+        // ݻ
+        $tmp_config =& $this->config;
 
         // ƥʤ
         if ($event == 'finalStream') {
@@ -177,6 +161,9 @@ echo "</pre>";
                 if (!$this->LoadLib($keys['file'])) {
                     // ٥Ⱥ
                     $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
+                    if ($keys['force']) {
+                        trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_WEBAPP_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
+                    }
                     continue;
                 }
 
@@ -274,6 +261,10 @@ echo "</pre>";
                             eval('$component =' . $ref . ' new ' . $classname . '(' . $eval_args . ');' ); 
                         }
                         $this->setComponent($name, $component);
+                    } else {
+                        if ($keys['force']) {
+                            trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_WEBAPP_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
+                        }
                     }
                     break;
 
@@ -329,15 +320,14 @@ echo "</pre>";
      * եɤ߹
      *
      * @access private
-     * @param string ٥̾
      * @param string եΥ
      * @return array ե
      */
-    function readConfig($event, $config_type)
+    function readConfig($config_type)
     {
         $config = array();
         foreach ($config_type as $type => $file) {
-            $reader =& SyL_Config::getObject($type, $file, $this->getComponent(SYL_CONTROLLER_NAME), $event);
+            $reader =& SyL_Config::getObject($type, $file, $this->getComponent(SYL_CONTROLLER_NAME));
             $reader->parseXml();
             $config += $reader->getConfig();
         }
