@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.20 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.21 2007/04/30 13:15:57 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,9 +44,9 @@ ob_implicit_flush(0);
 set_magic_quotes_runtime(0);
 
 /**
- * եɤ߹९饹
+ * ե륯饹
  */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_DefinesReader.php';
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
 /**
  * ƥʥ饹
  */
@@ -66,10 +66,10 @@ define('SYL_CONTROLLER_NAME', 'controller');
  *   ήȼܥ٥Ƚ
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.20 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.21 2007/04/30 13:15:57 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -193,7 +193,7 @@ class SyL_Controller
         define('SYL_APP_DIR', SYL_WEBAPP_DIR . '/app/' . $config['app_name']);
 
         // ɤ߹
-        SyL_DefinesReader::readConfig($this->defines_file_name);
+        call_user_func(array(&$this, 'readDefines'));
 
         // ǥ쥯ȥ
         $this->action_dir = SYL_APP_DIR . '/actions';
@@ -241,6 +241,27 @@ class SyL_Controller
         return $singleton;
     }
 
+    /**
+     * ɤ߹
+     *
+     * @access public
+     */
+    function readDefines()
+    {
+        $config_files = array();
+        // ץꥱͤɤ߹
+        $config_files[] = SYL_APP_DIR . "/{$this->defines_file_name}";
+        if (!file_exists($config_files[0])) {
+            array_shift($config_files);
+        }
+        // Хͤɤ߹
+        $config_files[] = SYL_WEBAPP_CONFIG_DIR . "/{$this->defines_file_name}";
+
+        // åѤʤ
+        $config =& SyL_Config::getObject('defines', $config_files, $this);
+        $config->parseXml();
+    }
+
     /**
      * 
      *
