@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,10 @@
  * ܾ󥯥饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.12 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.14 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -51,13 +51,6 @@ class SyL_Router
      * @var string
      */
     var $action_file_default = 'index.php';
-    /**
-     * ĥҥȽ
-     *
-     * @access protected
-     * @var bool
-     */
-    var $ext = true;
     /**
      * URLγĥ
      *
@@ -72,13 +65,6 @@ class SyL_Router
      * @var string
      */
     var $exe_ext = '.php';
-    /**
-     * PATH_INFO
-     *
-     * @access protected
-     * @var string
-     */
-    var $pathinfo = array();
     /**
      * ե
      *
@@ -99,7 +85,7 @@ class SyL_Router
      * @access protected
      * @var string
      */
-    var $class_name = '';
+    var $action_class = '';
 
     /**
      * 󥹥ȥ饯
@@ -122,20 +108,26 @@ class SyL_Router
      */
     function &getObject(&$data, $rule)
     {
-        $class_name = 'SyL_Router' . ucfirst($rule);
-        include_once SYL_INCLUDE_DIR . "/framework/Router/{$class_name}.php";
-        $router =& new $class_name();
-        $router->createProperty($data);
+        $classname = 'SyL_Router' . ucfirst($rule);
+        include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
+        $router =& new $classname();
+        $router->createActionInfo($data);
         return $router;
     }
 
     /**
      * ܾ󥪥֥ȤΥץѥƥ
+     *
+     * $this->action_name
+     * $this->action_file
+     * $this->action_class
+     *
+     
      *
      * @access protected
      * @param object ꥯȥ֥
      */
-    function createProperty(&$data)
+    function createActionInfo(&$data)
     {
     }
 
@@ -169,31 +161,9 @@ class SyL_Router
      */
     function getClassName()
     {
-        return $this->class_name;
+        return $this->action_class;
     }
 
-    /**
-     * PATH_INFO
-     *
-     * @access public
-     * @return array PATH_INFO
-     */
-    function getPathInfoArray()
-    {
-        return $this->pathinfo;
-    }
-
-    /**
-     * ǥ쥯ȥȥСб
-     *
-     * @access public
-     * @param string ѥ
-     * @return bool true: OKfalse: 顼
-     */
-    function isInvalidPath($pathinfo)
-    {
-        return preg_match('/\.\.\//', preg_quote($pathinfo, '/'));
-    }
 }
 
 ?>
