@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.1 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,10 +36,10 @@
  * 쥤ȥӥ塼饹
  *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.1 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayout extends SyL_View
@@ -68,11 +68,13 @@ class SyL_ViewLayout extends SyL_View
     {
         parent::SyL_View($context, $data);
 
+        $config_files = array();
         // 쥤
-        $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
-        $reader =& SyL_Config::getObject('layouts', $config_file, $context->controller);
-        $reader->parseXml();
-        $this->config += $reader->getConfig();
+        $config_files[] = SYL_APP_DIR . "/{$this->layout_file_name}";
+
+        $config =& SyL_Config::getObject('layouts', $config_files, $context->controller);
+        $config->parseXml();
+        $this->config = $config->getConfig();
 
         // ƥĥפ򥻥å
         $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
